@@ -51,11 +51,11 @@ def ensure_clean_working_tree() -> None:
 
 def get_head() -> Commit:
     """Get the head commit with its parent(s)"""
-    cmd = ["git", "log", "--pretty=%h %p", "-n", "1"]
+    cmd = ["git", "log", "--pretty=%h,%p", "-n", "1"]
     result = run(cmd, stdout=PIPE)
     print("git log stdout:", result.stdout)
-    shas = result.stdout.decode().strip().split(" ")
-    return Commit(*shas)
+    head, parents = result.stdout.decode().strip().split(",")
+    return Commit(head, *parents.split(" "))
 
 
 def get_repo_name() -> str:
