@@ -77,11 +77,14 @@ def apply(args: Namespace) -> None:
     try:
         planfile = _planfile(head.sha)
         plans.download(args.workspace, planfile)
+        print("Could not find plan for head commit")
     except PlanNotFound:
+        print("Checking for empty merge")
         if head.second_parent and head.is_empty_merge:
             planfile = _planfile(head.second_parent)
             plans.download(args.workspace, planfile)
         else:
+            print("Commit is not an empty merge, re-raising")
             raise
     tf = Terraform(TF_DIR)
     tf.select_workspace(args.workspace)
